@@ -1,10 +1,8 @@
-from __future__ import division, print_function, absolute_import
 from itertools import product
 from numpy.testing import (assert_, assert_allclose,
-                           assert_equal, assert_no_warnings)
+                           assert_equal, assert_no_warnings, suppress_warnings)
 import pytest
 from pytest import raises as assert_raises
-from scipy._lib._numpy_compat import suppress_warnings
 import numpy as np
 from scipy.optimize._numdiff import group_columns
 from scipy.integrate import solve_ivp, RK23, RK45, DOP853, Radau, BDF, LSODA
@@ -492,7 +490,7 @@ def test_events():
 
         assert_equal(res.y_events[0].shape, (0,))
         assert_equal(res.y_events[1].shape, (1, 2))
-        assert_equal(res.y_events[2].shape, (1, 2))        
+        assert_equal(res.y_events[2].shape, (1, 2))
         assert np.isclose(
             event_rational_2(res.t_events[1][0], res.y_events[1][0]), 0)
         assert np.isclose(
@@ -590,7 +588,7 @@ def test_first_step():
                           t_span[1], first_step=-1)
             assert_raises(ValueError, method, fun_rational, t_span[0], y0,
                           t_span[1], first_step=5)
-    
+
 
 def test_t_eval():
     rtol = 1e-3
@@ -893,7 +891,7 @@ def test_args():
 
     # sys3 is actually two decoupled systems. (x, y) form a
     # linear oscillator, while z is a nonlinear first order
-    # system with equilibria at z=0 and z=1.  If k > 0, z=1
+    # system with equilibria at z=0 and z=1. If k > 0, z=1
     # is stable and z=0 is unstable.
 
     def sys3(t, w, omega, k, zfinal):
